searchData={"items":[{"type":"module","title":"SGP30","doc":"According to the [datasheet](https://www.mouser.com/datasheet/2/682/Sensirion_Gas_Sensors_SGP30_Datasheet_EN-1148053.pdf), the sensor must\nbe initialized and the caller must start a measurement every second.\n`SGP30` handles this for you once initialized it will take a measurement\nevery second and you would simply call `SGP30.state` to get the\nmost current results.\n\n```elixir\niex()> {:ok, sgp} = SGP30.start_link()\niex()> SGP30.state\n%SGP30{\n  address: 88,\n  co2_eq_ppm: 421,\n  ethanol_raw: 17934,\n  h2_raw: 13113,\n  i2c: #Reference<0.7390235.92137012.02842>,\n  serial: 16613135,\n  tvoc_ppb: 17\n}\n```","ref":"SGP30.html"},{"type":"module","title":"Monitoring - SGP30","doc":"Each measurement uses `:telemetry.span/3` for duration and error tracking and\nalso emits an event on successful measurement with the current system time in\nthe metadata. This allows you to use the `:telemetry` tooling to track reported\nvalues over time and monitor the results of the sensor.\n\n`SGP30` also measures the raw values at the same time. This are typically not\nneeded, but are useful in calibration and tracking potential hardware failures.\n\nExpected events reported ¬\n\n| name | measurement | meta |\n| --- | --- | --- |\n| `[:sgp30, :measure]` | `%SGP30{}` | `%{system_time: System.monotonic_time()}` |\n| `[:sgp30, :measure, :start]` | `%{system_time: System.monotonic_time()}` | `%{}` |\n| `[:sgp30, :measure, :stop]` | `%{duration: integer()}` | `%{optional(:error) => any()}` |\n| `[:sgp30, :measure, :exception]` | `%{duration: integer()}` | `%{kind: :throw\\:error\\:exit, reason: term(), stacktrace: list()}` |\n| `[:sgp30, :measure_raw]` | `%SGP30{}` | `%{system_time: System.monotonic_time()}` |\n| `[:sgp30, :measure_raw, :start]` | `%{system_time: System.monotonic_time()}` | `%{}` |\n| `[:sgp30, :measure_raw, :stop]` | `%{duration: integer()}` | `%{optional(:error) => any()}` |\n| `[:sgp30, :measure_raw, :exception]` | `%{duration: integer()}` | `%{kind: :throw\\:error\\:exit, reason: term(), stacktrace: list()}` |\n\n\n**Note:** The `:stop` event will only include the `:error` key in the meta data\non I2C read errors that are reported, but not neccesarily thrown as an exception.\nAlso, a `:stop` event after a successful read will not include the `:error` key.","ref":"SGP30.html#module-monitoring"},{"type":"function","title":"SGP30.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"SGP30.html#child_spec/1"},{"type":"function","title":"SGP30.start_link/1","doc":"","ref":"SGP30.html#start_link/1"},{"type":"function","title":"SGP30.state/1","doc":"","ref":"SGP30.html#state/1"},{"type":"type","title":"SGP30.t/0","doc":"","ref":"SGP30.html#t:t/0"},{"type":"module","title":"SGP30.CRC","doc":"","ref":"SGP30.CRC.html"},{"type":"function","title":"SGP30.CRC.calculate/1","doc":"","ref":"SGP30.CRC.html#calculate/1"},{"type":"function","title":"SGP30.CRC.check/1","doc":"","ref":"SGP30.CRC.html#check/1"},{"type":"extras","title":"SGP30","doc":"# SGP30\nInterface with SGP30 gas sensor with elixir.\n\nFor more info on the sensor, see the [datasheet](https://www.mouser.com/datasheet/2/682/Sensirion_Gas_Sensors_SGP30_Datasheet_EN-1148053.pdf).\n\nCurrently tested with the [Adafruit breakout board](https://www.adafruit.com/product/3709),\nbut others should work as well.\n\n# Installation\n\n```elixir\ndef deps do\n  {:sgp30, \"~> 0.1\"}\nend\n```\n\n# Usage\n\nAccording to the [datasheet](https://www.mouser.com/datasheet/2/682/Sensirion_Gas_Sensors_SGP30_Datasheet_EN-1148053.pdf), the sensor must\nbe initialized and the caller must start a measurement every second.\n`SGP30` handles this for you once initialized it will take a measurement\nevery second and you would simply call `SGP30.state` to get the\nmost current results.\n\n```elixir\niex()> {:ok, sgp} = SGP30.start_link()\niex()> SGP30.state\n%SGP30{\n  address: 88,\n  co2_eq_ppm: 421,\n  ethanol_raw: 17934,\n  h2_raw: 13113,\n  i2c: #Reference<0.7390235.92137012.02842>,\n  serial: 16613135,\n  tvoc_ppb: 17\n}\n```","ref":"readme.html"},{"type":"extras","title":"Monitoring - SGP30","doc":"Each measurement uses `:telemetry.span/3` for duration and error tracking and\nalso emits an event on successful measurement with the current system time in\nthe metadata. This allows you to use the `:telemetry` tooling to track reported\nvalues over time and monitor the results of the sensor.\n\n`SGP30` also measures the raw values at the same time. This are typically not\nneeded, but are useful in calibration and tracking potential hardware failures.\n\nExpected events reported ¬\n\n| name | measurement | meta |\n| --- | --- | --- |\n| `[:sgp30, :measure]` | `%SGP30{}` | `%{system_time: System.monotonic_time()}` |\n| `[:sgp30, :measure, :start]` | `%{system_time: System.monotonic_time()}` | `%{}` |\n| `[:sgp30, :measure, :stop]` | `%{duration: integer()}` | `%{optional(:error) => any()}` |\n| `[:sgp30, :measure, :exception]` | `%{duration: integer()}` | `%{kind: :throw\\:error\\:exit, reason: term(), stacktrace: list()}` |\n| `[:sgp30, :measure_raw]` | `%SGP30{}` | `%{system_time: System.monotonic_time()}` |\n| `[:sgp30, :measure_raw, :start]` | `%{system_time: System.monotonic_time()}` | `%{}` |\n| `[:sgp30, :measure_raw, :stop]` | `%{duration: integer()}` | `%{optional(:error) => any()}` |\n| `[:sgp30, :measure_raw, :exception]` | `%{duration: integer()}` | `%{kind: :throw\\:error\\:exit, reason: term(), stacktrace: list()}` |\n\n\n**Note:** The `:stop` event will only include the `:error` key in the meta data\non I2C read errors that are reported, but not neccesarily thrown as an exception.\nAlso, a `:stop` event after a successful read will not include the `:error` key.","ref":"readme.html#monitoring"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.2.4 - Changelog","doc":"#","ref":"changelog.html#v0-2-4"},{"type":"extras","title":"Changed - Changelog","doc":"- Allow circuits_i2c 2.0 to be used (Thanks @fhunleth!)","ref":"changelog.html#changed"},{"type":"extras","title":"v0.2.3 - Changelog","doc":"#","ref":"changelog.html#v0-2-3"},{"type":"extras","title":"Added - Changelog","doc":"- Allow I2C address to be set with `:address` option (Thanks @fhunleth!)","ref":"changelog.html#added"},{"type":"extras","title":"v0.2.2 - Changelog","doc":"This update just allows `circuits_i2c ~> 1.0` and `telemetry ~> 1.0`\nbut introduces no functional changes. (thanks @krns! :heart:)","ref":"changelog.html#v0-2-2"},{"type":"extras","title":"v0.2.1 - Changelog","doc":"#","ref":"changelog.html#v0-2-1"},{"type":"extras","title":"Added - Changelog","doc":"- CRC's are now checked after reads","ref":"changelog.html#added"},{"type":"extras","title":"0.2.0 - Changelog","doc":"* Breaking Changes\n  * module renamed from `Sgp30` => `SGP30`\n  * values now include units\n    * `tvoc` => `tvoc_ppb`\n    * `eco2` => `co2_eq_ppm`\n  * `:serial` is now an 48bit integer\n\n* Enhancments\n  * added support for `:telemetry` - `start`, `stop`, and `exception`\n    events are reported along with the measurements. See `README.md`\n    for more details.","ref":"changelog.html#0-2-0"},{"type":"extras","title":"0.1.1 - Changelog","doc":"* Bug Fixes\n  * Fix `Logger.debug/1` undefined error\n  * Adjusted polling time for more accurate measurements\n  * Fixed `ethanol` misspelling\n\n* Enhancements\n  * Remove then \"measuring...\" log message to keep logs clean","ref":"changelog.html#0-1-1"},{"type":"extras","title":"0.1.0 - Changelog","doc":"* Initial release","ref":"changelog.html#0-1-0"}],"content_type":"text/markdown"}